import { Component, EventEmitter, Input, OnInit, } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { Bu2Model, MyBu2Model } from 'src/app/shared/model/bu2.model';
import { Bu3Model, MyBu3Model } from 'src/app/shared/model/bu3.model';
import { Bu2Service } from 'src/app/shared/services/bu2.service';
import { Bu3Service } from 'src/app/shared/services/bu3.service';
interface table {
  currentPage: number,
  page: number[],
  search: string
}
@Component({
  selector: 'app-section-registration',
  templateUrl: './section-registration.component.html',
  styleUrls: ['./section-registration.component.scss']
})
export class SectionRegistrationComponent implements OnInit {
  bu3List: Bu3Model[] = []
  bu3: Bu3Model = new MyBu3Model({})
  bu3Table: table = {
    currentPage: 1,
    page: Array.from({ length: 1 }, (_, i) => i + 1),
    search: ""
  }
  bu3Modal: table = {
    currentPage: 1,
    page: Array.from({ length: 1 }, (_, i) => i + 1),
    search: ""
  }
  bu2List: Bu2Model[] = []
  bu2: Bu2Model = new MyBu2Model({})
  bu2Modal: table = {
    currentPage: 1,
    page: Array.from({ length: 1 }, (_, i) => i + 1),
    search: ""
  }
  currentModal = ""
  constructor(private bu3Service: Bu3Service,
    private bu2Service: Bu2Service,
    private toastr: ToastrService
  ) { }
  ngOnInit(): void {
    this.getBu3List()
    this.getBu2List()
  }
  getBu3List() {
    this.bu3Service.getList().subscribe(response => {
      this.bu3List = response
      this.onBu3TableSearchChange()
    })
  }
  onBu3TableSearchChange() {
    this.bu3Table.currentPage = 1
    this.bu3Table.page = Array.from({ length: Math.ceil(this.filterBu3Table().length / 10) }, (_, i) => i + 1);
  }
  filterBu3Table() {
    return this.bu3List.filter(x => x.bu3id.toLowerCase().includes(this.bu3Table.search) ||
      x.tdesc.toLowerCase().includes(this.bu3Table.search) ||
      x.edesc.toLowerCase().includes(this.bu3Table.search))
  }
  selectBu3(bu3?: Bu3Model) {
    this.bu3 = new MyBu3Model(bu3 || {})
    this.selectBu2()
    if (this.bu3.parent) {
      this.bu2Service.getById(this.bu3.parent).subscribe(response => {
        this.bu2 = new MyBu2Model(response)
      })
    }
  }
  bu3idChange() {
    const bu3 = this.bu3List.find(x => x.bu3id == this.bu3.bu3id)
    this.selectBu3(bu3 || new MyBu3Model({ bu3id: this.bu3.bu3id }))
  }
  onBu3ModalSearchChange() {
    this.bu3Modal.currentPage = 1
    this.bu3Modal.page = Array.from({ length: Math.ceil(this.filterBu3Modal().length / 10) }, (_, i) => i + 1);
  }
  filterBu3Modal() {
    return this.bu3List.filter(x => x.bu3id.toLowerCase().includes(this.bu3Modal.search) ||
      x.tdesc.toLowerCase().includes(this.bu3Modal.search) ||
      x.edesc.toLowerCase().includes(this.bu3Modal.search))
  }
  addBu3() {
    // this.bu3Service.post(this.bu3).subscribe((response:any) => {
    //   if (response.success) {
    //     this.getBu3List()
    //   }
    // })
  }
  deleteBu3(bu3: Bu3Model) {
    // this.bu3Service.delete(new MyBu3Model(bu3)).subscribe((response:any) => {
    //   if (response.success) {
    //     this.getBu3List()
    //   }
    // })
  }

  getBu2List() {
    this.bu2Service.getList().subscribe(response => {
      this.bu2List = response
      this.onBu2ModalSearchChange()
    })
  }
  onBu2ModalSearchChange() {
    this.bu2Modal.currentPage = 1
    this.bu2Modal.page = Array.from({ length: Math.ceil(this.filterBu2Modal().length / 10) }, (_, i) => i + 1);
  }
  bu2idChange() {
    const bu2 = this.bu2List.find(x => x.bu2id == this.bu2.bu2id)
    this.selectBu2(bu2 || new MyBu2Model({ bu2id: this.bu2.bu2id }))
  }
  filterBu2Modal() {
    return this.bu2List.filter(x => x.bu2id.toLowerCase().includes(this.bu2Modal.search) ||
      x.tdesc.toLowerCase().includes(this.bu2Modal.search) ||
      x.edesc.toLowerCase().includes(this.bu2Modal.search))
  }
  selectBu2(bu2?: Bu2Model) {
    this.bu2 = new MyBu2Model(bu2 || {})
  }

  showSuccess() {
    this.toastr.success('บันทึกข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  showSuccessEdit() {
    this.toastr.success('เเก้ไขข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  showSuccessDelete() {
    this.toastr.success('ลบข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
}

